syscall: rename z_object_validate -> k_object_validate

Rename internal API to not use z_/Z_.

Signed-off-by: Anas Nashif <anas.nashif@intel.com>
diff --git a/kernel/userspace.c b/kernel/userspace.c
index f3e73ef..ffece57 100644
--- a/kernel/userspace.c
+++ b/kernel/userspace.c
@@ -721,7 +721,7 @@
 	}
 }
 
-int z_object_validate(struct k_object *ko, enum k_objects otype,
+int k_object_validate(struct k_object *ko, enum k_objects otype,
 		       enum _obj_init_check init)
 {
 	if (unlikely((ko == NULL) ||
@@ -759,7 +759,7 @@
 	struct k_object *ko;
 
 	/* By the time we get here, if the caller was from userspace, all the
 	 * necessary checks have been done in z_object_validate(), which takes
 	 * place before the object is initialized.
 	 *
 	 * This function runs after the object has been initialized and
@@ -759,7 +759,7 @@
 
 	/* By the time we get here, if the caller was from userspace, all the
-	 * necessary checks have been done in z_object_validate(), which takes
+	 * necessary checks have been done in k_object_validate(), which takes
 	 * place before the object is initialized.
 	 *